Persistence
============

Sometimes, you need to schedule timed events over a long period of time; too
long to trust that a single process will stay running.  Fritter includes a
module, :py:mod:`fritter.persistence.json`, that can help you do just that.

Conceptual Overview
-------------------



.. literalinclude:: json_instance.py

.. literalinclude:: json_methods_example.py
